

import request from '@/utils/request'
// 查询检测商品列表
export function listInspectionGoods(query) {
  return request({
    url: '/system/inspectionGoods/listSystem',
    method: 'get',
    params: query
  })
}

// 查询检测商品详细
export function getInspectionGoods(id) {
  return request({
    url: '/system/inspectionGoods/' + id,
    method: 'get'
  })
}

// 新增检测商品
export function addInspectionGoods(data) {
  return request({
    url: '/system/inspectionGoods/add',
    method: 'post',
    data: data
  })
}

// 修改检测商品
export function updateInspectionGoods(data) {
  return request({
    url: '/system/inspectionGoods/edit',
    method: 'post',
    data: data
  })
}

// 删除检测商品
export function delInspectionGoods(id) {
  return request({
    url: '/system/inspectionGoods/del?idList=' + id,
    method: 'post'
  })
}
//首页推荐
export function homeGoods(data) {
  return request({
    url: '/system/homeGoods/add',
    method: 'post',
    data:data
  })
}
//提交审核
export function tijiaoshenhe(data) {
  return request({
    url: '/system/inspectionGoods/examine',
    method: 'post',
    data:data
  })
}

