<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">

      <el-form-item label="商品标题" prop="title">
        <el-input
          v-model="queryParams.title"
          placeholder="请输入商品标题"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="上下架" prop="title">
<!--        <el-input-->
<!--          v-model="queryParams.isListing"-->
<!--          placeholder="上架输入1下架输入0"-->
<!--          clearable-->
<!--          @keyup.enter.native="handleQuery"-->
<!--        />-->
        <el-select v-model="queryParams.isListing" placeholder="请选择">
          <el-option
            v-for="item in sxjarr"
            :key="item.value"
            :label="item.label"
            :value="item.value">
          </el-option>
        </el-select>
      </el-form-item>


      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:inspectionGoods:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['system:inspectionGoods:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:inspectionGoods:remove']"
        >删除</el-button>
      </el-col>

      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="inspectionGoodsList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="商品标题" align="center" prop="title" />
      <el-table-column label="商品分类" align="center" prop="categoryName" />
      <el-table-column label="合作商" align="center" prop="partnerName" />
      <el-table-column label="价格（元）" align="center" prop="price" >
        <template slot-scope="scope">
        <div>{{scope.row.price/100}}</div>
        </template>
      </el-table-column>
      <el-table-column label="封面图" align="center" prop="image" width="100">
        <template slot-scope="scope">
          <image-preview :src="scope.row.image" :width="50" :height="50"/>
        </template>
      </el-table-column>
      <el-table-column label="商品图片" align="center" prop="images" width="100">
        <template slot-scope="scope">
          <image-preview :src="scope.row.images" :width="50" :height="50"/>
        </template>
      </el-table-column>
      <el-table-column label="特价/正常" align="center" prop="isSpecial">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.is_special" :value="scope.row.isSpecial"/>
        </template>
      </el-table-column>
      <el-table-column label="状态" align="center" prop="listingStatus">
        <template slot-scope="scope">

          <div v-if="scope.row.listingStatus == 0 || scope.row.listingStatus == null">

          </div>
          <div v-if="scope.row.listingStatus == 1">
            <el-tag type="warning">待审核</el-tag>
          </div>
          <div v-if="scope.row.listingStatus == 2">
            <el-tag type="success">已通过</el-tag>
          </div>
          <div v-if="scope.row.listingStatus == 3">
            <el-tag type="danger">未通过</el-tag>
          </div>
        </template>
      </el-table-column>

      <el-table-column label="下架/上架" align="center" prop="isListing">
        <template slot-scope="scope">
          <el-tag type="success" v-if="scope.row.isListing == '1'">上架</el-tag>
          <el-tag type="danger"  v-if="scope.row.isListing == '0'">下架</el-tag>
        </template>
      </el-table-column>


<!--      <el-table-column label="不参与/参与" align="center" prop="isAttend">-->
<!--        <template slot-scope="scope">-->
<!--          <dict-tag :options="dict.type.yes_no" :value="scope.row.isAttend"/>-->
<!--        </template>-->
<!--      </el-table-column>-->

      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            v-if="scope.row.isListing == '0'"
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="getfj(scope.row)"
            v-hasPermi="['system:inspectionGoods:edit']"
          >上架</el-button>
          <el-button
            v-if="scope.row.isListing == '1'"
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="getfj(scope.row)"
            v-hasPermi="['system:inspectionGoods:edit']"
          >下架</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:inspectionGoods:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:inspectionGoods:remove']"
          >删除</el-button>
          <el-button
            size="mini"
            type="text"
            v-if="scope.row.listingStatus == 1"
            icon="el-icon-edit"
            @click="shenhe(scope.row)"
            v-hasPermi="['system:inspectionGoods:remove']"
          >审核</el-button>


        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

<!--    -->
    <el-dialog title="审核" :visible.sync="dialogFormVisible">
      <el-form :model="froms">

        <el-form-item label="是否通过" :label-width="formLabelWidth">
          <el-select v-model="froms.listingStatus" placeholder="请选择">
            <el-option label="通过" value="2"></el-option>
            <el-option label="拒绝" value="3"></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="备注" :label-width="formLabelWidth">
          <el-input type="textarea" v-model="froms.rejectReason"></el-input>

        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button @click="dialogFormVisible = false">取 消</el-button>
        <el-button type="primary" @click="tjshenhe()">确 定</el-button>
      </div>
    </el-dialog>
    <!-- 添加或修改检测商品对话框 新增 修改 -->

    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="120px">
        <el-form-item label="商品标题" prop="title">
          <el-input v-model="form.title" placeholder="请输入商品标题" />
        </el-form-item>
        <el-form-item label="价格" prop="price">
<!--          <el-input v-model="form.price" placeholder="请输入价格" />-->
          <el-input-number v-model="form.price " :precision="2" :step="0.1" :max="999999999" :min="0.01"></el-input-number>
        </el-form-item>
<!--        合作商id-->
        <el-form-item label="合作商" prop="price">
          <el-select v-model="form.partnerId" placeholder="请选择">
            <el-option
              v-for="item in mallPartnersList"
              :key="item.partnerId"
              :label="item.partnerName"
              :value="item.partnerId">
            </el-option>
          </el-select>
        </el-form-item>
<!--        商品id-->
        <el-form-item label="商品分类" prop="price">
          <el-select v-model="form.goodsCategoryId" placeholder="请选择">
            <el-option
              v-for="item in categoryList"
              :key="item.id"
              :label="item.categoryName"
              :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="封面图" prop="image">
          <image-upload v-model="form.image"/>
        </el-form-item>
        <el-form-item label="商品图片" prop="images">
          <image-upload v-model="form.images"/>
        </el-form-item>
        <el-form-item label="特价/正常" prop="isSpecial">
          <el-radio-group v-model="form.isSpecial">
            <el-radio
              v-for="dict in dict.type.is_special"
              :key="dict.value"
              :label="parseInt(dict.value)"
            >{{dict.label}}</el-radio>
          </el-radio-group>
        </el-form-item>
        <el-form-item label="详细描述" prop="goodsDesc">
          <editor v-model="form.goodsDesc" :min-height="192"/>
        </el-form-item>


      </el-form>
      <div slot="footer" class="dialog-footer">

        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
  import {  listCategory,  } from "../inspection/api/inspection";
  import {fjPartners, listMallPartners,} from "../inspection/api/Partner";
  import { tijiaoshenhe, homeGoods, listInspectionGoods, getInspectionGoods, delInspectionGoods, addInspectionGoods, updateInspectionGoods } from "./api/inspectionGoods";
  import request from "@/utils/request";
  import DictTag from "@/components/DictTagOld/index.vue";

  export default {
    name: "InspectionGoods",
    components:{DictTag},
    dicts: ['is_special', 'yes_no'],
    data() {

      return {
        dialogFormVisible: false,
        froms: {
          id:0,
          listingStatus:'2',
          rejectReason:'',
          name: '',
          region: '',
          date1: '',
          date2: '',
          delivery: false,
          type: [],
          resource: '',
          desc: ''
        },
        formLabelWidth: '120px',
        sxjarr:[
          {
            value: '1',
            label: '上架'
          },
          {
            value: '0',
            label: '下架'
          },
        ],
        // 遮罩层
        loading: true,
        // 选中数组
        ids: [],
        // 非单个禁用
        single: true,
        // 非多个禁用
        multiple: true,
        // 显示搜索条件
        showSearch: true,
        // 总条数
        total: 0,
        // 检测商品表格数据
        inspectionGoodsList: [],
        // 弹出层标题
        title: "",
        // 是否显示弹出层
        open: false,
        // 查询参数
        queryParams: {
          pageNum: 1,
          pageSize: 10,
          id: null,
          title: null,
          goodsCategoryId: null,
          partnerId: null,
          price: null,
          image: null,
          images: null,
          isSpecial: null,
          goodsDesc: null,
          isListing: null,
          isAttend: null,
          orderNum: null,
        },
        //合作商
        mallPartnersList: [],
        //请求合作商参数
        hzsarr: {
          pageNum: 1,
          pageSize: 9999,
          userId: null,
          type: null,
          partnerName: null,
          partnerLogo: null,
          shopImages: null,
          contactNumber: null,
          address: null,
          province: null,
          city: null,
          area: null,
          partnerCategoryId: null,
          averageScore: null,
          longitude: null,
          latitude: null,
          workTime: null,
          salesNum: null,
          orderNum: null,
          isBanned: null,
        },
        //分类请求参数
        flarr: {
          pageNum: 1,
          pageSize: 999,
          pid: null,
          categoryName: null,
          orderNum: null
        },
        categoryList: [],
        // 表单参数
        form: {},
        // 表单校验
        rules: {
          title: [
            { required: true, message: "商品标题不能为空", trigger: "blur" }
          ],
          price: [
            { required: true, message: "价格不能为空", trigger: "blur" }
          ],
          image: [
            { required: true, message: "封面图不能为空", trigger: "blur" }
          ],
          images: [
            { required: true, message: "商品图片不能为空", trigger: "blur" }
          ],
          isSpecial: [
            { required: true, message: "特价/正常不能为空", trigger: "change" }
          ],
        }
      };
    },
    created() {
      this.dict = {type:{}}
      for (let i = 0; i < this.$options.dicts.length; i++) {
        request({
          url: '/rescue/dict/data/type/'+this.$options.dicts[i],
          method: 'get'
        }).then(res=>{
          this.$set(this.dict.type,this.$options.dicts[i],res.data)
        })
      }
      this.getList();
    },
    methods: {
      tjshenhe(item){
        let arr = {
          id:this.froms.id,
          listingStatus:this.froms.listingStatus,
          rejectReason:this.froms.rejectReason
        }
        tijiaoshenhe(arr).then(res =>{
          this.$modal.msgSuccess("修改成功");
          this.dialogFormVisible = false
          this.getList()
        })
      },
      shenhe(item){
        this.dialogFormVisible = true
        this.froms.id = item.id

      },
      /** 查询检测商品列表 */
      getList() {
        this.loading = true;
        listInspectionGoods(this.queryParams).then(response => {
          this.inspectionGoodsList = response.rows;
          this.inspectionGoodsList.price=this.inspectionGoodsList.price / 100
          this.total = response.total;
          this.loading = false;
        });
        listMallPartners(this.hzsarr).then(response => {
          this.mallPartnersList = response.rows;
          console.log('查询合作商管理列表 ',this.mallPartnersList)
        });
        listCategory(this.flarr).then(response => {
          this.categoryList = response.data.list;
          console.log('查询分类管理列表 ',this.categoryList)

        });
      },
      //推荐
      gettui(id){
        let data = {
          goodsId : id
        }
        homeGoods(data).then(res=>{
          console.log(res)
          this.$modal.msgSuccess("修改成功");
          this.getList()
        })
      },
      //上下架管理
      getfj(row){
        console.log(row,'1111')
        let arr = row
        if (arr.isListing=='1'){
          arr.isListing='0'
        }else if(arr.isListing=='0'){
          arr.isListing='1'
        }
        console.log(arr.isListing,'222')
        updateInspectionGoods(arr).then(res =>{
          this.$modal.msgSuccess("修改成功");
          this.getList()
        })
      },
      // 取消按钮
      cancel() {
        this.open = false;
        this.reset();
      },
      // 表单重置
      reset() {
        this.form = {
          id: null,
          title: null,
          goodsCategoryId: null,
          partnerId: null,
          price: null,
          image: null,
          images: null,
          isSpecial: null,
          goodsDesc: null,
          isListing: null,
          isAttend: null,
          orderNum: null,
          createTime: null,
          createBy: null,
          updateTime: null,
          updateBy: null
        };
        this.resetForm("form");
      },
      /** 搜索按钮操作 */
      handleQuery() {
        this.queryParams.pageNum = 1;
        this.getList();
      },
      /** 重置按钮操作 */
      resetQuery() {
        this.resetForm("queryForm");
        this.handleQuery();
      },
      // 多选框选中数据
      handleSelectionChange(selection) {
        this.ids = selection.map(item => item.id)
        this.single = selection.length!==1
        this.multiple = !selection.length
      },
      /** 新增按钮操作 */
      handleAdd() {
        this.reset();
        this.open = true;
        this.title = "添加检测商品";
      },
      /** 修改按钮操作 */
      handleUpdate(row) {
        this.reset();
        const id = row.id || this.ids
        getInspectionGoods(id).then(response => {
          this.form = response.data;
          this.form.price = this.form.price / 100
          this.open = true;
          this.title = "修改检测商品";
        });
      },
      /** 提交按钮 */
      submitForm() {
        this.form.price = this.form.price * 100
        console.log('提交的时候', this.form.price)
        this.$refs["form"].validate(valid => {
          if (valid) {
            if (this.form.id != null) {

              updateInspectionGoods(this.form).then(response => {
                this.$modal.msgSuccess("修改成功");
                this.open = false;
                this.getList();
              });
            } else {

              addInspectionGoods(this.form).then(response => {
                this.$modal.msgSuccess("新增成功");
                this.open = false;
                this.getList();
              });
            }
          }
        });
      },
      /** 删除按钮操作 */
      handleDelete(row) {
        const ids = row.id || this.ids;
        this.$modal.confirm('是否确认删除检测商品编号为"' + ids + '"的数据项？').then(function() {
          return delInspectionGoods(ids);
        }).then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        }).catch(() => {});
      },
      /** 导出按钮操作 */
      handleExport() {
        this.download('system/inspectionGoods/export', {
          ...this.queryParams
        }, `inspectionGoods_${new Date().getTime()}.xlsx`)
      }
    }
  };
</script>
